=====================================================
``psyclone.psyir.transformations.omp_taskwait_trans``
=====================================================

.. automodule:: psyclone.psyir.transformations.omp_taskwait_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.omp_taskwait_trans
